pub enum Meta {
PathValue(PathValue),
PathList(PathList),
Expr(Expr),
Verbatim(TokenStream),
}Variants
PathValue(PathValue)
A path followed by an equal sign and a single Meta — e.g. my_attribute = my_value.
PathList(PathList)
A path followed by a wrapped list of Metas — e.g. my_attribute(one, two, three).
This accepts an optional equal sign before the list — e.g. my_attribute = (one, two, three).
Expr(Expr)
An expression — e.g. my_attribute, 42, "hello" or a + b.
Verbatim(TokenStream)
A verbatim token stream — e.g. [<=>].
This is the fallback for any other Meta that does not match the other variants.
Implementations
Sourceimpl Meta
impl Meta
pub fn path(&self) -> Result<&Path>
Sourcepub fn path_str(&self) -> String
pub fn path_str(&self) -> String
Returns the path as a string if it is a valid path or an empty string if it is not a path.
pub fn is_path_or_list(&self) -> bool
pub fn is_path_or_empty_list(&self) -> bool
pub fn as_path(&self) -> Result<&Path>
pub fn as_path_list(&self) -> Result<&PathList>
pub fn as_path_value(&self) -> Result<&PathValue>
pub fn as_value(&self) -> Result<&Meta>
pub fn as_expr_or_value_expr(&self) -> Result<&Expr>
pub fn as_expr(&self) -> Result<&Expr>
pub fn as_verbatim(&self, msg: impl Display) -> Result<&TokenStream>
pub fn assert_directive(&self, directive: &str) -> Result<&Self>